@@ -176,8 +176,9 @@
     (setq zip (sratsimp zip))
     (or
      (like 0 zip) (like 0 ($radcan zip)) (like 0 ($radcan ($expand zip)))
+     (like 0 (mfuncall '$expintegral_e_simp zip))
      (mtell "should vanish, but it does not ~:M~%" zip))))
-    
+
 (defun check-fss (cfs fss x)
   (let (($gcd '$spmod) ($algebraic t))
     (and 
@@ -291,7 +292,7 @@
 (defun polynomial-filter (p x f)
   (let (($gcd '$spmod) ($algebraic t) ($ratfac nil) 
 	($ratprint nil) ($radexpand nil))
-    (setq p (sratsimp p x)) ;; Get rid of terms like sqr(5)^2, %i^2...
+    (setq p (sratsimp p)) ;; Get rid of terms like sqr(5)^2, %i^2...
     (setq p ($mysqfr p x))
     (setq p (if (mtimesp p) (margs p) (list p)))
     (let ((q 1) (n))
