@@ -1,16 +1,14 @@
 ;; ezunits: yet another units package for Maxima
 ;; This program copyright 2008 by Robert Dodier.
 ;; I release this program under the terms of the
-;; GNU General Public License, version 2.
+;; GNU General Public License.
 
 ;; Process tex(a`b): throw away the backtick, texify a,
 ;; and texify b with all symbols in b output as mathrm.
 
 (defun tex-ezunits (x l r)
-  (append
-    (tex (second x) l r 'mparen 'mparen)
-    (list "\\;")
-    (tex (mathrm-ify (third x)) l r 'mparen 'mparen)))
+  (setq l (tex (second x) l '("\\;") lop (caar x)))
+  (tex (mathrm-ify (third x)) l r (caar x) rop))
 
 ;; If a symbol has a texword property, preserve it.
 ;; Otherwise replace each symbol with a gensym which has a mathrm texword property.
