@@ -1,4 +1,4 @@
-#| Copyright 2007 by Barton Willis
+#| Copyright 2007, 2008 by Barton Willis
 
   This is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License,
@@ -10,7 +10,8 @@
 
 
 ($load '$polynomialp)
-($load '$topoly)
+(if (not ($get '$to_poly '$version)) ($load '$topoly))
+
 (mfuncall '$declare '$one_to_one '$feature)
 (mfuncall '$declare '$sinh '$one_to_one)
 (mfuncall '$declare '$log  '$one_to_one)
@@ -122,7 +123,7 @@
 	   
 (defun freeof-floats (e)
   (if ($mapatom e) (not (or (floatp e) ($bfloatp e)))
-    (every 'freeof-floats (margs e))))
+    (every 'freeof-floats (margs (ratdisrep e)))))
 
 ;; Splitify an expression; this does e -> ((e1, boolean) (e2, boolean), ...). Examples:
 
@@ -163,7 +164,7 @@
 
 	  (t (list (list e t))))))
 	       
-(defun m> (a b &optional (expand nil))
+(defun m> (a b &optional (expand nil) (use-splitify t))
   (let* ((z) (sgn) (z-split) (acc nil))
     (setq a ($ratdisrep a))
     (setq b ($ratdisrep b))
@@ -183,15 +184,15 @@
 	  ;; Catch four easy cases before we splitify z. Without the checks for the easy cases, 
 	  ;; we'd get things like |x| > 1 --> (-1 < x & x < 0) or (x = 0) or (x < 1, x > 0).
 
-	  ;; First, |a| > b --> (b < 0) or (a > b, b >= 0).
+	  ;; First, |a| > b --> (b < 0) or (a > b, b >= 0) or (-a > b, b >= 0).
 
 	  ((and (op-equalp a 'mabs) ($freeof 'mabs '$min '$max b))
 	   (setq a (first (margs a)))
 	   (opapply 'mor (list
 			  (opapply 'mand (list (m> 0 b)))
-			  (opapply 'mand (list (m>= b 0) (m> a b))))))
-	  
-
+			  (opapply 'mand (list (m>= b 0) (m> a b)))
+			  (opapply 'mand (list (m>= b 0) (m> (neg a) b))))))
+		    
 	  ;; Second, a > |b| == a > b and  a > -b.
 
 	  ((and (op-equalp b 'mabs) ($freeof 'mabs '$min '$max a))
@@ -207,31 +208,17 @@
 	  
           ((and (op-equalp b '$max) ($freeof 'mabs '$min '$max a))
 	   (opapply 'mand (mapcar #'(lambda (s) (m> a s)) (margs b))))
-	  
-	  ;; Finally, take care of the abs, max, and min cases that the previous
-	  ;; four cases miss. 
-	  
-	  ((not ($freeof 'mabs '$min '$max z))
-	   (setq z-split (splitify z))
-	   (dolist (zk z-split)
-	     (push `((mand) ,(m> (first zk) 0) ,@(rest zk)) acc))
-	   (push '(mor) acc)
-	   (simplifya acc nil))
-	  	  
-	  ;; Do a * b > 0 --> (a > 0, b > 0) or (a < 0, b < 0). We only do this when
-	  ;; z has two or more non-constant factors. This check seems spendy--is there
-	  ;; a way to bailout before we get here?
-
-          ((and (op-equalp z 'mtimes) expand) 
-	   (make-positive-product (margs z)))
-
+	  	  	  
 	  ;; Do z^n > 0 --> z # 0  n even,  z > 0, n odd.
 	  ((and (op-equalp z 'mexpt) (integerp (third z)))
 	   (if (even (third z)) (m-neq (second z) 0) (m> (second z) 0)))
 
 	  ;; Do f(a) > f(b), where f is increasing --> a > b.
 	  ((and (not ($mapatom a)) (not ($mapatom b)) (eq (mop a) (mop b)) ($featurep (mop a) '$increasing))
-	   (m> (first (margs a)) (first (margs b))))
+	   (opapply 'mand (list 
+			   (m> (first (margs a)) (first (margs b)))
+			   (in-real-domain a)
+			   (in-real-domain b))))
 	  
 	  ;; Do f(a) > f(b), where f is decreasing --> a < b.
 	  ((and (not ($mapatom a)) (not ($mapatom b)) (eq (mop a) (mop b)) ($featurep (mop a) '$decreasing))
@@ -243,10 +230,26 @@
 		(eq (compare-using-empty-context (second a) 1) ">"))
 	   (m> (first (margs a)) (first (margs b))))
 	  
+	  ;; Do a * b > 0 --> (a > 0, b > 0) or (a < 0, b < 0). We only do this when
+	  ;; z has two or more non-constant factors. This check seems spendy--is there
+	  ;; a way to bailout before we get here?
+
+          ((and (op-equalp z 'mtimes) expand) 
+	   (make-positive-product (margs z)))
+	  ;; Finally, take care of the abs, max, and min cases that the previous
+	  ;; four cases miss. 
+	  
+	  ((and use-splitify (op-equalp z '$max '$min 'mabs 'mtimes 'mplus))
+	   (setq z-split (splitify z))
+	   (dolist (zk z-split)
+	     (push `((mand) ,(m> (first zk) 0 expand nil) ,@(rest zk)) acc))
+	   (push '(mor) acc)
+	   (simplifya acc nil))
+
           (t 
 	   (opapply 'mgreaterp (list z 0))))))
               
-(defun m= (a b)
+(defun m= (a b &optional (use-splitify t))
   (let* ((z (sub a b)) (nz) (acc) (z-split) (sgn  (compare-using-empty-context a b)))
     (setq z (if (freeof-floats z) ($factor z) z))
     
@@ -272,20 +275,25 @@
       (expand-and-over-or 
        (take '(mand) nz (opapply 'mor (mapcar #'(lambda (s) (m= s 0)) (margs z))))))
 
-     ((not ($freeof 'mabs '$min '$max z))
+     ((and use-splitify (op-equalp z '$max '$min 'mabs 'mtimes 'mplus))
       (setq z-split (splitify z))
       (dolist (zk z-split)
-	(push `((mand) ,(m= (first zk) 0) ,@(rest zk)) acc))
+	(push `((mand) ,(m= (first zk) 0 nil) ,@(rest zk)) acc))
       (push '(mor) acc)
       (expand-and-over-or (simplifya acc nil)))
      
      (t (take '(mequal) z 0)))))
 
 (defun m-neq (a b)
-  (let ((sgn  (compare-using-empty-context a b)))
-    (cond ((member sgn '("#" "<" ">" $notcomparable) :test 'equal) t)
-	  ((equal sgn "=") nil)
-	  (t (opcons 'mor (m> a b  t) (m> b a t))))))
+  (let ((save-context $context) (new-context (gensym)) (sgn))
+    (unwind-protect
+     (progn
+       (setq sgn (mnqp a b))
+       (cond ((or (eq sgn t) (eq sgn nil)) sgn)
+	     ((eq $domain '$real) (opcons 'mor (m> a b t) (m> b a t)))
+	     (t (take '(mnot) (m= a b)))))
+     (if ($member new-context $contexts) ($killcontext new-context))
+     (setq $context save-context))))
 	  
 (defun m>= (a b)
   (let ((sgn (compare-using-empty-context a b)))
