@@ -745,9 +745,11 @@
 	(positions ()))
     (dotimes (i n)
       (add-edge `(,i ,(+ n i)) g)
-      (let* ((u (+ i n)) (v (+ (mod (+ i d) n) n))
-	     (e1 (min v u)) (e2 (max v u)))
-	(add-edge `(,e1 ,e2) g))
+      (when (or (/= n (* 2 d))
+		(< i d))
+	(let* ((u (+ i n)) (v (+ (mod (+ i d) n) n))
+	       (e1 (min v u)) (e2 (max v u)))
+	(add-edge `(,e1 ,e2) g)))
       (let* ((u (mod (1+ i) n)) (e1 (min u i)) (e2 (max u i)))
 	(add-edge `(,e1 ,e2) g)))
     (dotimes (i n)
@@ -1058,8 +1060,8 @@
 	  (add-edge e g))))
     (dotimes (i n)
       (push `((mlist simp) ,i ((mlist simp)
-			       ,($sin (m// (m* 2.0 i '$%pi) n))
-			       ,($cos (m// (m* 2.0 i '$%pi) n))))
+			       ,($sin (m// (m* 2.0 i pi) n))
+			       ,($cos (m// (m* 2.0 i pi) n))))
 	    positions))
     ($set_positions (cons '(mlist simp) positions) g)
     g))
