@@ -1,17 +1,26 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2006/12/21 03:42:11 
-;;; Using Lisp CMU Common Lisp CVS Head 2006-12-02 00:15:46 (19D)
+;;; Compiled by f2cl version:
+;;; ("f2cl1.l,v 1.212 2009/01/08 18:58:49 rtoy Exp $"
+;;;  "f2cl2.l,v 1.37 2008/02/22 22:19:33 rtoy Exp $"
+;;;  "f2cl3.l,v 1.6 2008/02/22 22:19:33 rtoy Exp $"
+;;;  "f2cl4.l,v 1.7 2008/02/22 22:19:34 rtoy Exp $"
+;;;  "f2cl5.l,v 1.199 2009/01/07 19:16:59 rtoy Exp $"
+;;;  "f2cl6.l,v 1.48 2008/08/24 00:56:27 rtoy Exp $"
+;;;  "macros.l,v 1.112 2009/01/08 12:57:19 rtoy Exp $")
+
+;;; Using Lisp CMU Common Lisp Snapshot 2008-12 (19E)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':array)
 ;;;           (:array-slicing t) (:declare-common nil)
 ;;;           (:float-format double-float))
 
-(in-package "LAPACK")
+(in-package :lapack)
 
 
 (let* ((zero 0.0) (one 1.0))
   (declare (type (double-float 0.0 0.0) zero)
-           (type (double-float 1.0 1.0) one))
+           (type (double-float 1.0 1.0) one)
+           (ignorable zero one))
   (defun dgeevx
          (balanc jobvl jobvr sense n a lda wr wi vl ldvl vr ldvr ilo ihi scale
           abnrm rconde rcondv work lwork iwork info)
@@ -673,10 +682,10 @@
                             fortran-to-lisp::ilo fortran-to-lisp::ihi nil
                             fortran-to-lisp::abnrm nil nil nil nil nil
                             fortran-to-lisp::info)
-           :calls '(fortran-to-lisp::dtrsna fortran-to-lisp::drot
-                    fortran-to-lisp::dlartg fortran-to-lisp::idamax
-                    fortran-to-lisp::dlapy2 fortran-to-lisp::dscal
-                    fortran-to-lisp::dnrm2 fortran-to-lisp::dgebak
+           :calls '(fortran-to-lisp::drot fortran-to-lisp::dlartg
+                    fortran-to-lisp::idamax fortran-to-lisp::dlapy2
+                    fortran-to-lisp::dscal fortran-to-lisp::dnrm2
+                    fortran-to-lisp::dgebak fortran-to-lisp::dtrsna
                     fortran-to-lisp::dtrevc fortran-to-lisp::dhseqr
                     fortran-to-lisp::dorghr fortran-to-lisp::dlacpy
                     fortran-to-lisp::dgehrd fortran-to-lisp::dgebal
